import { Module } from '@nestjs/common';
import { ConfigModule, ConfigService } from '@nestjs/config';
import { MoviesController } from './movies.controller';
import { createOmdbEnrichedDataService } from './services/omdbEnrichedDataService';
import { createInternalProvider } from './integration/movies/internal';
import { createOmdbProviderByApiKey } from './integration/movies/omdb';

@Module({
    imports: [ConfigModule.forRoot({ ignoreEnvFile: true })],
    controllers: [MoviesController],
    providers: [
        {
            provide: 'enrichedDataService',
            useFactory: async (configService: ConfigService) =>
                createOmdbEnrichedDataService(
                    createInternalProvider(),
                    createOmdbProviderByApiKey(
                        configService.getOrThrow('OMDB_API_KEY'),
                    ),
                ),
            inject: [ConfigService],
        },
    ],
})
// eslint-disable-next-line @typescript-eslint/no-extraneous-class
export class AppModule {}
