import { describe, it, expect } from '@jest/globals';
import movie3532674 from '../../../resources/movies/3532674.json';
import movie5979300 from '../../../resources/movies/5979300.json';
import movie11043689 from '../../../resources/movies/11043689.json';
import movie11528860 from '../../../resources/movies/11528860.json';
import { normalizeRawInternalData } from './converters';

describe('normalizeRawInternalData', () => {
    it('normalizes data correctly for 3532674', () => {
        const result = normalizeRawInternalData(movie3532674);
        expect(result).toEqual({
            availableLanguages: ['de', 'en'],
            duration: 119,
            imdbId: 'tt0401792',
            internalId: 3532674,
            localDescription:
                'Im Sündenpfuhl Sin City werden drei Geschichten parallel erzählt: Der Polizist Hartigan jagt einen Pädophilen, der Outlaw Dwight muss im Rotlichtbezirk untertauchen und dem Schläger Marv wird ein Mord angehängt. ',
            localTitle: 'Sin City',
            originalLanguage: 'en',
            productionYear: 2005,
            ratings: [
                {
                    source: 'Internal',
                    value: '3.9/5',
                },
            ],
            studios: ['Studiocanal', 'Paramount'],
        });
    });

    it('normalizes data correctly for 5979300', () => {
        const result = normalizeRawInternalData(movie5979300);
        expect(result).toEqual({
            availableLanguages: ['de', 'en'],
            duration: 127,
            imdbId: 'tt0097576',
            internalId: 5979300,
            localDescription:
                '1912: Der junge Indiana Jones will Grabräubern das Kreuz von Coronado abluchsen, um es in ein Museum zu bringen. Nach einem Zeitsprung ins Jahr 1938 kämpft Indy wieder um das Kreuz, diesmal erfolgreich. Anschließend soll er den Heiligen Gral suchen.',
            localTitle: 'Indiana Jones und der letzte Kreuzzug',
            originalLanguage: 'en',
            productionYear: 1989,
            ratings: [
                {
                    source: 'Internal',
                    value: '4.2/5',
                },
            ],
            studios: ['Paramount'],
        });
    });

    it('normalizes data correctly for 11043689', () => {
        const result = normalizeRawInternalData(movie11043689);
        expect(result).toEqual({
            availableLanguages: ['de', 'en'],
            duration: 120,
            imdbId: 'tt0076759',
            internalId: 11043689,
            localDescription:
                'Der im Exil lebende Jedi-Ritter Obi-Wan Kenobi nimmt sich einen Mann namens Luke Skywalker als Schüler. Zusammen helfen sie der Rebellion, die Pläne des bösen Imperiums und des Sith-Lords Darth Vader zu vereiteln. ',
            localTitle: 'Star Wars: Eine neue Hoffnung',
            originalLanguage: 'en',
            productionYear: 1977,
            ratings: [
                {
                    source: 'Internal',
                    value: '4.5/5',
                },
            ],
            studios: ['FOX', 'Paramount'],
        });
    });

    it('normalizes data correctly for 11528860', () => {
        const result = normalizeRawInternalData(movie11528860);
        expect(result).toEqual({
            availableLanguages: ['de', 'en'],
            duration: 75,
            imdbId: 'tt0061852',
            internalId: 11528860,
            localDescription:
                'Unter der Obhut des Panthers Baghira wächst das Findelkind Mogli bei einer Wolfsfamilie auf. Doch da erschüttert die Rückkehr des menschenfressenden Tigers Shir Khan den Dschungel. Die Sorge um Mogli zwingt Baghira zu der einzig möglichen Entscheidung.',
            localTitle: 'Das Dschungelbuch',
            originalLanguage: 'en',
            productionYear: 1967,
            ratings: [
                {
                    source: 'Internal',
                    value: '4.4/5',
                },
            ],
            studios: ['Disney'],
        });
    });
});
