import { describe, it, expect } from '@jest/globals';

import { createInternalProvider } from './index';

describe('createInternalProvider', () => {
    const client = createInternalProvider();

    it('returns correct data for 11528860', async () => {
        const result = await client.getMetadataByInternalId(11528860);
        expect(result).toMatchObject({
            availableLanguages: expect.any(Array),
            duration: 75,
            internalId: 11528860,
            imdbId: 'tt0061852',
            localDescription: expect.any(String),
            localTitle: 'Das Dschungelbuch',
            originalLanguage: 'en',
            productionYear: 1967,
            studios: ['Disney'],
            ratings: expect.arrayContaining([
                {
                    source: expect.any(String),
                    value: expect.any(String),
                },
            ]),
        });
    });

    it('returns undefined for non-existent internal id', async () => {
        const result = await client.getMetadataByInternalId(999999);
        expect(result).toBeUndefined();
    });

    it('returns data for imdb id', async () => {
        const result = await client.getMetadataByImdbId('tt0061852');
        expect(result).toMatchObject({
            availableLanguages: expect.any(Array),
            duration: 75,
            internalId: 11528860,
            imdbId: 'tt0061852',
            localDescription: expect.any(String),
            localTitle: 'Das Dschungelbuch',
            originalLanguage: 'en',
            productionYear: 1967,
            studios: ['Disney'],
            ratings: expect.arrayContaining([
                {
                    source: expect.any(String),
                    value: expect.any(String),
                },
            ]),
        });
    });

    it('returns undefined for non-existent imdb id', async () => {
        const result = await client.getMetadataByImdbId('tt99999999999');
        expect(result).toBeUndefined();
    });
});
