import type { InternalProvider } from '../../../types';
import { normalizeRawInternalData } from './converters';
import { createStorageClient } from './storage';

export const createInternalProvider = (): InternalProvider => {
    const storageClient = createStorageClient();

    return {
        getMetadataByInternalId: async (internalId) => {
            const rawInternalData =
                await storageClient.getMetadataByInternalId(internalId);
            if (!rawInternalData) {
                return undefined;
            }

            return normalizeRawInternalData(rawInternalData);
        },
        getMetadataByImdbId: async (imdbId) => {
            const rawInternalData =
                await storageClient.getMetadataByImdbId(imdbId);
            if (!rawInternalData) {
                return undefined;
            }

            return normalizeRawInternalData(rawInternalData);
        },
        getAllMetadata: async () => {
            const rawInternalData = await storageClient.getAllMetadata();
            return rawInternalData.map(normalizeRawInternalData);
        },
    };
};
