import { describe, it, expect } from '@jest/globals';

import { createStorageClient } from './storage';

describe('createStorageClient', () => {
    const client = createStorageClient();

    it('returns data for 11528860', async () => {
        const result = await client.getMetadataByInternalId(11528860);
        expect(result).toMatchObject({
            description: expect.any(String),
            duration: 75,
            id: 11528860,
            imdbId: 'tt0061852',
            languages: expect.any(Array),
            originalLanguage: 'en',
            productionYear: 1967,
            studios: ['Disney'],
            title: 'Das Dschungelbuch',
            userrating: {
                countStar1: expect.any(Number),
                countStar2: expect.any(Number),
                countStar3: expect.any(Number),
                countStar4: expect.any(Number),
                countStar5: expect.any(Number),
                countTotal: expect.any(Number),
            },
        });
    });

    it('returns undefined for non-existent internal id', async () => {
        const result = await client.getMetadataByInternalId(999999);
        expect(result).toBeUndefined();
    });

    it('returns data for tt0061852', async () => {
        const result = await client.getMetadataByImdbId('tt0061852');
        expect(result).toMatchObject({
            description: expect.any(String),
            duration: 75,
            id: 11528860,
            imdbId: 'tt0061852',
            languages: expect.any(Array),
            originalLanguage: 'en',
            productionYear: 1967,
            studios: ['Disney'],
            title: 'Das Dschungelbuch',
            userrating: {
                countStar1: expect.any(Number),
                countStar2: expect.any(Number),
                countStar3: expect.any(Number),
                countStar4: expect.any(Number),
                countStar5: expect.any(Number),
                countTotal: expect.any(Number),
            },
        });
    });

    it('returns undefined for non-existent imdb id', async () => {
        const result = await client.getMetadataByImdbId('tt99999999999');
        expect(result).toBeUndefined();
    });
});
