import type { OmdbProvider } from '../../../types';
import { createOmdbApiClient } from './apiClient';
import { normalizeRawOmdbData } from './converters';
import type { OmdbApiClient } from './types';

export const createOmdbProviderByApiClient = (
    apiClient: OmdbApiClient,
): OmdbProvider => {
    return {
        getMetadata: async (imdbId) => {
            const rawOmdbData = await apiClient.fetchMetadata(imdbId);
            if (!rawOmdbData) {
                return undefined;
            }

            return normalizeRawOmdbData(rawOmdbData);
        },
    };
};

export const createOmdbProviderByApiKey = (apiKey: string): OmdbProvider => {
    const apiClient = createOmdbApiClient(apiKey);

    return createOmdbProviderByApiClient(apiClient);
};
