import { describe, it, expect } from '@jest/globals';
import { createTestOmdbEnrichedDataService } from '../utils/testHelpers';

describe('createOmdbEnrichedDataService', () => {
    const servicePromise = createTestOmdbEnrichedDataService();

    it('returns correct data for 3532674', async () => {
        const service = await servicePromise;
        const result = service.getMetadataByInternalId(3532674);

        expect(result).toEqual({
            actors: ['Mickey Rourke', 'Clive Owen', 'Bruce Willis'],
            availableLanguages: ['de', 'en'],
            awards: '38 wins & 54 nominations',
            boxOffice: '$74,103,820',
            contentRating: 'R',
            description:
                "Four tales of crime adapted from Frank Miller's popular comics, focusing around a muscular brute who's looking for the person responsible for the death of his beloved Goldie (Jaime King), a man fed up with Sin City's corrupt law enforcement who takes the law into his own hands after a horrible mistake, a cop who risks his life to protect a girl from a deformed pedophile and a hitman looking to make a little cash.",
            directors: [
                'Frank Miller',
                'Quentin Tarantino',
                'Robert Rodriguez',
            ],
            duration: 119,
            dvdReleaseDate: '03 Sep 2016',
            genres: ['Crime', 'Thriller'],
            imdbId: 'tt0401792',
            internalId: 3532674,
            localDescription:
                'Im Sündenpfuhl Sin City werden drei Geschichten parallel erzählt: Der Polizist Hartigan jagt einen Pädophilen, der Outlaw Dwight muss im Rotlichtbezirk untertauchen und dem Schläger Marv wird ein Mord angehängt. ',
            localTitle: 'Sin City',
            originalLanguage: 'en',
            posterUrl:
                'https://m.media-amazon.com/images/M/MV5BODZmYjMwNzEtNzVhNC00ZTRmLTk2M2UtNzE1MTQ2ZDAxNjc2XkEyXkFqcGdeQXVyMTQxNzMzNDI@._V1_SX300.jpg',
            productionCountries: ['United States'],
            productionYear: 2005,
            ratings: [
                {
                    source: 'Internet Movie Database',
                    value: '8.0/10',
                },
                {
                    source: 'Rotten Tomatoes',
                    value: '76%',
                },
                {
                    source: 'Metacritic',
                    value: '74/100',
                },
                {
                    source: 'Internal',
                    value: '3.9/5',
                },
            ],
            releaseDate: '01 Apr 2005',
            studios: ['Studiocanal', 'Paramount'],
            title: 'Sin City',
            type: 'movie',
            writers: ['Frank Miller', 'Robert Rodriguez'],
        });
    });

    it('returns correct data for 5979300', async () => {
        const service = await servicePromise;
        const result = service.getMetadataByInternalId(5979300);

        expect(result).toEqual({
            actors: ['Harrison Ford', 'Sean Connery', 'Alison Doody'],
            availableLanguages: ['de', 'en'],
            awards: 'Won 1 Oscar. 9 wins & 24 nominations total',
            boxOffice: '$197,171,806',
            contentRating: 'PG-13',
            description:
                'An art collector appeals to Indiana Jones to embark on a search for the Holy Grail. He learns that another archaeologist has disappeared while searching for the precious goblet, and the missing man is his own father, Dr. Henry Jones. The artifact is much harder to find than they expected, and its powers are too much for those impure of heart.',
            directors: ['Steven Spielberg'],
            duration: 127,
            dvdReleaseDate: '28 Jan 2014',
            genres: ['Action', 'Adventure'],
            imdbId: 'tt0097576',
            internalId: 5979300,
            localDescription:
                '1912: Der junge Indiana Jones will Grabräubern das Kreuz von Coronado abluchsen, um es in ein Museum zu bringen. Nach einem Zeitsprung ins Jahr 1938 kämpft Indy wieder um das Kreuz, diesmal erfolgreich. Anschließend soll er den Heiligen Gral suchen.',
            localTitle: 'Indiana Jones und der letzte Kreuzzug',
            originalLanguage: 'en',
            posterUrl:
                'https://m.media-amazon.com/images/M/MV5BY2Q0ODg4ZmItNDZiYi00ZWY5LTg2NzctNmYwZjA5OThmNzE1XkEyXkFqcGdeQXVyMjM4MzQ4OTQ@._V1_SX300.jpg',
            productionCountries: ['United States'],
            productionYear: 1989,
            ratings: [
                {
                    source: 'Internet Movie Database',
                    value: '8.2/10',
                },
                {
                    source: 'Rotten Tomatoes',
                    value: '84%',
                },
                {
                    source: 'Metacritic',
                    value: '65/100',
                },
                {
                    source: 'Internal',
                    value: '4.2/5',
                },
            ],
            releaseDate: '24 May 1989',
            studios: ['Paramount'],
            title: 'Indiana Jones and the Last Crusade',
            type: 'movie',
            writers: ['Jeffrey Boam', 'George Lucas', 'Menno Meyjes'],
        });
    });

    it('returns correct data for tt0076759', async () => {
        const service = await servicePromise;
        const result = service.getMetadataByImdbId('tt0076759');

        expect(result).toEqual({
            actors: ['Mark Hamill', 'Harrison Ford', 'Carrie Fisher'],
            availableLanguages: ['de', 'en'],
            awards: 'Won 6 Oscars. 65 wins & 31 nominations total',
            boxOffice: '$460,998,507',
            contentRating: 'PG',
            description:
                'The Imperial Forces, under orders from cruel Darth Vader, hold Princess Leia hostage in their efforts to quell the rebellion against the Galactic Empire. Luke Skywalker and Han Solo, captain of the Millennium Falcon, work together with the companionable droid duo R2-D2 and C-3PO to rescue the beautiful princess, help the Rebel Alliance and restore freedom and justice to the Galaxy.',
            directors: ['George Lucas'],
            duration: 120,
            dvdReleaseDate: '10 Oct 2016',
            genres: ['Action', 'Adventure', 'Fantasy'],
            imdbId: 'tt0076759',
            internalId: 11043689,
            localDescription:
                'Der im Exil lebende Jedi-Ritter Obi-Wan Kenobi nimmt sich einen Mann namens Luke Skywalker als Schüler. Zusammen helfen sie der Rebellion, die Pläne des bösen Imperiums und des Sith-Lords Darth Vader zu vereiteln. ',
            localTitle: 'Star Wars: Eine neue Hoffnung',
            originalLanguage: 'en',
            posterUrl:
                'https://m.media-amazon.com/images/M/MV5BOTA5NjhiOTAtZWM0ZC00MWNhLThiMzEtZDFkOTk2OTU1ZDJkXkEyXkFqcGdeQXVyMTA4NDI1NTQx._V1_SX300.jpg',
            productionCountries: ['United States'],
            productionYear: 1977,
            ratings: [
                {
                    source: 'Internet Movie Database',
                    value: '8.6/10',
                },
                {
                    source: 'Rotten Tomatoes',
                    value: '93%',
                },
                {
                    source: 'Metacritic',
                    value: '90/100',
                },
                {
                    source: 'Internal',
                    value: '4.5/5',
                },
            ],
            releaseDate: '25 May 1977',
            studios: ['FOX', 'Paramount'],
            title: 'Star Wars: Episode IV - A New Hope',
            type: 'movie',
            writers: ['George Lucas'],
        });
    });

    it('returns correct data for tt0061852', async () => {
        const service = await servicePromise;
        const result = service.getMetadataByImdbId('tt0061852');

        expect(result).toEqual({
            actors: ['Phil Harris', 'Sebastian Cabot', 'Louis Prima'],
            availableLanguages: ['de', 'en'],
            awards: 'Nominated for 1 Oscar. 6 wins & 4 nominations total',
            boxOffice: '$141,843,612',
            contentRating: 'G',
            description:
                "Abandoned after an accident, baby Mowgli is taken and raised by a family of wolves. As the boy grows older, the wise panther Bagheera realizes he must be returned to his own kind in the nearby man-village. Baloo the bear, however, thinks differently, taking the young Mowgli under his wing and teaching him that living in the jungle is the best life there is. Bagheera realizes that Mowgli is in danger, particularly from Shere Khan the tiger who hates all people. When Baloo finally comes around, Mowgli runs off into the jungle where he survives a second encounter with Kaa the snake and finally, with Shere Khan. It's the sight of a pretty girl, however, that draws Mowgli to the nearby man-village and stay there.",
            directors: ['Wolfgang Reitherman'],
            duration: 75,
            dvdReleaseDate: '10 Aug 2016',
            genres: ['Animation', 'Adventure', 'Comedy'],
            imdbId: 'tt0061852',
            internalId: 11528860,
            localDescription:
                'Unter der Obhut des Panthers Baghira wächst das Findelkind Mogli bei einer Wolfsfamilie auf. Doch da erschüttert die Rückkehr des menschenfressenden Tigers Shir Khan den Dschungel. Die Sorge um Mogli zwingt Baghira zu der einzig möglichen Entscheidung.',
            localTitle: 'Das Dschungelbuch',
            originalLanguage: 'en',
            posterUrl:
                'https://m.media-amazon.com/images/M/MV5BYmY1MTA3NmUtYzJmZC00YTFjLTk2NzktYTJhMWQ0ZTlkNzJjXkEyXkFqcGdeQXVyNjc5NjEzNA@@._V1_SX300.jpg',
            productionCountries: ['United States'],
            productionYear: 1967,
            ratings: [
                {
                    source: 'Internet Movie Database',
                    value: '7.6/10',
                },
                {
                    source: 'Rotten Tomatoes',
                    value: '88%',
                },
                {
                    source: 'Metacritic',
                    value: '65/100',
                },
                {
                    source: 'Internal',
                    value: '4.4/5',
                },
            ],
            releaseDate: '18 Oct 1967',
            studios: ['Disney'],
            title: 'The Jungle Book',
            type: 'movie',
            writers: ['Larry Clemmons', 'Ralph Wright', 'Ken Anderson'],
        });
    });

    it('returns undefined for non-existent internal ID', async () => {
        const service = await servicePromise;
        const result = service.getMetadataByInternalId(999999999);

        expect(result).toBeUndefined();
    });

    it('returns undefined for correct ID for movie not present in internal database', async () => {
        const service = await servicePromise;
        const result = service.getMetadataByImdbId('tt7394674');

        expect(result).toBeUndefined();
    });

    it('returns correct search results for writer = George Lucas', async () => {
        const service = await servicePromise;
        const result = service.getSearchResults({ writers: 'George Lucas' });

        expect(result).toMatchObject([
            { title: 'Indiana Jones and the Last Crusade' },
            { title: 'Star Wars: Episode IV - A New Hope' },
        ]);
    });

    it('returns correct search results for writer = George Lucas and actor = Harrison Ford', async () => {
        const service = await servicePromise;
        const result = service.getSearchResults({
            actors: 'Harrison Ford',
            writers: 'George Lucas',
        });

        expect(result).toMatchObject([
            { title: 'Indiana Jones and the Last Crusade' },
            { title: 'Star Wars: Episode IV - A New Hope' },
        ]);
    });

    it('returns correct search results for writer = George Lucas and actor = Mark Hamill', async () => {
        const service = await servicePromise;
        const result = service.getSearchResults({
            actors: 'Mark Hamill',
            writers: 'George Lucas',
        });

        expect(result).toMatchObject([
            { title: 'Star Wars: Episode IV - A New Hope' },
        ]);
    });

    it('returns correct search results for title = The Jungle Book', async () => {
        const service = await servicePromise;
        const result = service.getSearchResults({ title: 'The Jungle Book' });

        expect(result).toMatchObject([{ title: 'The Jungle Book' }]);
    });

    it('returns correct search results for local title = Das Dschungelbuch', async () => {
        const service = await servicePromise;
        const result = service.getSearchResults({
            localTitle: 'Das Dschungelbuch',
        });

        expect(result).toMatchObject([{ title: 'The Jungle Book' }]);
    });

    it('returns correct search results for production year = 1967', async () => {
        const service = await servicePromise;
        const result = service.getSearchResults({ productionYear: 1967 });

        expect(result).toMatchObject([{ title: 'The Jungle Book' }]);
    });

    it('returns empty search results for writer = George Lucas and actor = Bruce Willis', async () => {
        const service = await servicePromise;
        const result = service.getSearchResults({
            actors: 'Bruce Willis',
            writers: 'George Lucas',
        });

        expect(result).toMatchObject([]);
    });

    it('returns empty search results for title = Blood Quantum', async () => {
        const service = await servicePromise;
        const result = service.getSearchResults({ title: 'Blood Quantum' });

        expect(result).toMatchObject([]);
    });

    it('returns correct search results for writer = gEoRgE lUcAs and actor = hArRiSoN fOrD', async () => {
        const service = await servicePromise;
        const result = service.getSearchResults({
            actors: 'hArRiSoN fOrD',
            writers: 'gEoRgE lUcAs',
        });

        expect(result).toMatchObject([
            { title: 'Indiana Jones and the Last Crusade' },
            { title: 'Star Wars: Episode IV - A New Hope' },
        ]);
    });
});
